@@ -13,6 +13,7 @@
 #endif
 
 #include "mt.h"
+#include "utils.h"
 #include "version.h"
 
 void print_trace(void)
@@ -40,12 +41,13 @@ void error_exit(char *format, ...)
 	va_start(ap, format);
 	(void)vfprintf(stderr, format, ap);
 	va_end(ap);
-	printf("\n\n\nDebug information:\n");
 	if (errno) fprintf(stderr, "errno: %d=%s (if applicable)\n", errno, strerror(errno));
 
 #if defined(__GLIBC__)
+	printf("\n\n\nDebug information:\n");
 	print_trace();
 #endif
+	dump_mem(SIGHUP);
 
 	fflush(NULL);
 
