@@ -1116,7 +1116,7 @@ int add_marker_if_changed(int f_index, proginfo *cur)
 {
 	int changed = 0;
 
-	if (lb[f_index].last_win != cur && (lb[f_index].marker_of_other_window || global_marker_of_other_window) && lb[f_index].marker_of_other_window != -1)
+	if (lb[f_index].last_win != cur && (lb[f_index].marker_of_other_window || global_marker_of_other_window) && lb[f_index].marker_of_other_window != (char)-1)
 	{
 		add_markerline(f_index, cur, MARKER_CHANGE, NULL);
 
@@ -1878,7 +1878,7 @@ char close_window(int winnr, proginfo *cur)
 		mvwprintw(mywin -> win, 1, 2, "Window %d/%d closed", winnr, subwinnr);
 		mvwprintw(mywin -> win, 2, 2, "%s", cur -> filename);
 		mvwprintw(mywin -> win, 3, 2, "Exit code: %d", WEXITSTATUS(cur -> last_exit_rc));
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		color_off(mywin, 1);
 
 		wmove(mywin -> win, 1, 2);
@@ -2021,7 +2021,7 @@ void add_pars_per_file(char *re, char *colorscheme, int n_buffer_lines, int buff
 	if (buffer_bytes != -1)
 		ppf[loop].buffer_bytes = buffer_bytes;
 
-	if (change_win_marker != -1)
+	if (change_win_marker != (char)-1)
 		ppf[loop].change_win_marker = change_win_marker;
 
 	if (fs != -1)
