@@ -36,6 +36,9 @@ int find_string(buffer *pbuf, char *find, int offset, char direction, mybool_t c
 	{
 		for(loop=offset; loop<pbuf -> curpos; loop++)
 		{
+			if ((pbuf -> be)[loop].Bline == NULL)
+				continue;
+
 			if (regexec(&regex, (pbuf -> be)[loop].Bline, 0, NULL, 0) == 0)
 			{
 				index = loop;
@@ -43,10 +46,13 @@ int find_string(buffer *pbuf, char *find, int offset, char direction, mybool_t c
 			}
 		}
 	}
-	else if (direction == -1)
+	else if (direction == (char)-1)
 	{
 		for(loop=offset; loop>=0; loop--)
 		{
+			if ((pbuf -> be)[loop].Bline == NULL)
+				continue;
+
 			if (regexec(&regex, (pbuf -> be)[loop].Bline, 0, NULL, 0) == 0)
 			{
 				index = loop;
@@ -67,7 +73,7 @@ void scrollback_find_popup(char **find_str, mybool_t *pcase_insensitive)
 
 	win_header(mywin, "Find");
 
-	dummy = edit_string(mywin, 3, 2, 40, 80, 0, *find_str, HELP_SCROLLBACK_EDIT_SEARCH_STRING, -1, &search_h, pcase_insensitive);
+	dummy = edit_string(mywin, 3, 2, 40, 80, 0, reuse_searchstring?*find_str:NULL, HELP_SCROLLBACK_EDIT_SEARCH_STRING, -1, &search_h, pcase_insensitive);
 	myfree(*find_str);
 	*find_str = dummy;
 
@@ -617,7 +623,7 @@ void merged_scrollback_with_search(char *search_for, mybool_t case_insensitive)
 				continue;
 			}
 
-			if (search_for != NULL)
+			if (search_for != NULL && lb[loop].be[last_check[loop]].Bline != NULL)
 			{
 				rc = regexec(&reg, lb[loop].be[last_check[loop]].Bline, 0, NULL, 0);
 
